@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.23 2008/10/04 11:07:27 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.28 2009/01/24 15:01:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -269,6 +269,22 @@ PcgTab gPcgTabStreetlampOff[] = {
 	},
 };
 
+PcgTab gPcgTabBootUnit[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"boot_unit",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabSignboard[] = {
 	{
 		// 
@@ -285,6 +301,22 @@ PcgTab gPcgTabSignboard[] = {
 	},
 };
 
+PcgTab gPcgTabLava[] = {
+	{
+		// 
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"water/lava",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabStairsUpTown[] = {
 	{
 		// 
@@ -1706,16 +1738,16 @@ PcgTab gPcgTabMnstr[] = {
 		"character/monster/devil/jack_o_lantern/",
 	},
 	{
-		MNSTR_KIND_LESSER_DEMON,
+		MNSTR_KIND_LESSER_DAEMON,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		100,
-		"character/monster/devil/lesser_demon/",
+		"character/monster/devil/lesser_daemon/",
 	},
 	{
-		MNSTR_KIND_GREATER_DEMON,
+		MNSTR_KIND_GREATER_DAEMON,
 		FACE_MJR_NULL, FACE_MNR_NULL,
 		100,
-		"character/monster/devil/greater_demon/",
+		"character/monster/devil/greater_daemon/",
 	},
 	/* ܥ */
 	{
@@ -1773,6 +1805,12 @@ PcgTab gPcgTabMnstr[] = {
 		100,
 		"character/monster/devil/xex/",
 	},
+	{
+		MNSTR_KIND_XX,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"character/monster/devil/xx/",
+	},
 	/**/
 	{
 		MNSTR_KIND_NULL,
