@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.65 2009/02/01 22:21:26 bowkenken Exp $
+* $Id: draw.h,v 1.66 2009/05/23 15:59:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -166,8 +166,11 @@ typedef unsigned long	flg_msg_t;
 /* åκԿ */
 #define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)
 
+/* åκʸ */
+#define	LS_MSG_MAX_LEN	(SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8)
+
 typedef struct {
-	char	msg[SCREEN_WIDTH * 4 + 1];
+	char	msg[LS_MSG_MAX_LEN + 1];
 	curs_attr_t	attr;
 } ls_msg_t;
 
