@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.218 2009/03/10 16:18:04 bowkenken Exp $
+* $Id: mnstr.c,v 1.219 2009/05/23 15:59:37 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1810,8 +1810,8 @@ void	mnstr_drop_key_item( mnstr_t *p )
 {
 	dun_t	*dun = get_dun();
 	star_drop_kind_t	kind;
-	static char	str[SCREEN_WIDTH * 8 + 1];
-	const long	max_len = SCREEN_WIDTH * 8;
+	static char	str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long	max_len = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
 
 	if( p == NULL )
 		return;
